import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:grouped_list/grouped_list.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shop_app/controllers/example_controller.dart';
import 'package:shop_app/screens/setting_detail/setting_detail.dart';

class ListRecord extends StatelessWidget {
  final ExampleController eventController = Get.find();

  @override
  Widget build(BuildContext context) {
    return Obx(() {
      if (eventController.events.isEmpty) return Center(child: Text('Empty'));

      return GroupedListView<RabbitRequest, String>(
        elements: eventController.events,
        groupBy: (element) {
          if (element.sessionEvent == 'start' ||
              element.sessionEvent == 'end') {
            var data = eventController.events
                .where((e) => e.sessionId == element.sessionId);
            return '${data.first.id.toString().padLeft(2, '0')}-${data.last.id.toString().padLeft(2, '0')}:${element.sessionId}';
          }

          return '${element.id.toString().padLeft(2, '0')}:${element.sessionId}';
        },
        groupSeparatorBuilder: (String groupByValue) => Text(groupByValue,
            textAlign: TextAlign.center,
            style: TextStyle(fontWeight: FontWeight.bold)),
        itemBuilder: (context, element) => Card(
          elevation: 8.0,
          margin: const EdgeInsets.symmetric(horizontal: 10.0, vertical: 6.0),
          child: SizedBox(
            child: GestureDetector(
              onTap: () => Navigator.pushNamed(
                  context, SettingDetailScreen.routeName,
                  arguments: element),
              child: ListTile(
                contentPadding: const EdgeInsets.symmetric(
                    horizontal: 20.0, vertical: 10.0),
                title: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text('Event Name  : ${element.eventName}'),
                    Text('Event Value : ${element.eventValue}'),
                    Text('Date Time   : ${element.time}'),
                    Container(
                      padding: EdgeInsets.symmetric(horizontal: 5),
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(5),
                        color: element.isSend ? Colors.lightBlue : Colors.grey,
                      ),
                      child: Text(
                        'Sent',
                        style: TextStyle(color: Colors.white),
                      ),
                    )
                  ],
                ),
                trailing: const Icon(Icons.arrow_forward),
              ),
            ),
          ),
        ),
        floatingHeader: true,
        order: GroupedListOrder.DESC,
      );
    });
  }
}
