import 'dart:core';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:get/utils.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';

import '../constants/app_constants.dart';

class RabbitConfigController {
  late String apiKey;
  late String encryptKey;
  late String collectionType;
  late int retentionDays;
  late int rotationTime;
  late int retryTime;
  late bool deleteAfterSent;
  late int cpu;
  late int memory;
  late int batteryLevel;
  late String dbType;
  late int sessionExpire;
  late int sessionAutoExpire;
  late bool offlineMode;
  late bool? consent;
  late bool permissionMaid;
  late int storageMin;
  late int storageMax;
  late bool debugMode;

  RabbitConfigController(RabbitDataConfig rdc) {
    apiKey = rdc.apiKey;
    encryptKey = rdc.encryptKey;
    collectionType = rdc.collectionType.name;
    retentionDays = rdc.retentionDays;
    rotationTime = rdc.rotationTime;
    retryTime = rdc.retryTime;
    deleteAfterSent = rdc.deleteAfterSent;
    cpu = rdc.cpu;
    memory = rdc.memory;
    batteryLevel = rdc.batteryLevel;
    dbType = rdc.dbType.name;
    sessionExpire = rdc.sessionExpire;
    sessionAutoExpire = rdc.sessionAutoExpire;
    offlineMode = rdc.offlineMode;
    debugMode = rdc.debugMode;

    if (debugMode) {
      baseURL = baseStaging;
    } else {
      baseURL = baseProd;
    }

    consent = rdc.consent;
    if (GetPlatform.isIOS) {
      permissionMaid = false;

      var deviceInfoPlugin = DeviceInfoPlugin();
      deviceInfoPlugin.deviceInfo.then((deviceInfo) {
        if (deviceInfo is IosDeviceInfo) {
          var version = deviceInfo.systemVersion!;
          var versionNum = int.parse(version.split('.').first);

          if (versionNum <= 13) {
            permissionMaid = rdc.permissionMaid;
          } else {
            Permission.appTrackingTransparency.isGranted
                .then((value) => permissionMaid = value);
          }
        } else {
          permissionMaid = rdc.permissionMaid;
        }
      });
    } else if (GetPlatform.isAndroid) {
      permissionMaid = rdc.permissionMaid;
    }

    storageMin = rdc.storageMin;
    storageMax = rdc.storageMax;
  }
}
