import 'package:package_info_plus/package_info_plus.dart';
import 'package:rdc_flutter_sdk/src/model/version.dart';
import 'package:rdc_flutter_sdk/src/util/file_helper.dart';
import 'package:shared_preferences/shared_preferences.dart';

class VersionController {
  var appVer = '';
  var appVerNum = '';
  var prevAppVer = '';
  var prevAppVerNum = '';
  var sdkVersion = '';

  Future<VersionController> init() async {
    await _init();
    await _hasData();
    return this;
  }

  Future<void> _init() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    appVer = packageInfo.version;
    appVerNum = packageInfo.buildNumber;
    sdkVersion = await FileHelper.getVersion();
  }

  Future<void> _hasData() async {
    final sharedPreference = await SharedPreferences.getInstance();

    // check first run app
    if (!sharedPreference.containsKey('appVer')) {
      await save(sharedPreference);
      return;
    }

    // new version app
    var version = Version();
    version.appVer = sharedPreference.getString('appVer')!;
    version.appVerNum = sharedPreference.getString('appVerNum')!;
    version.prevAppVer = sharedPreference.getString('prevAppVer');
    version.prevAppVerNum = sharedPreference.getString('prevAppVerNum');

    if (version.appVer != appVer || version.appVerNum != appVerNum) {
      prevAppVer = version.appVer;
      prevAppVerNum = version.appVerNum;
      await save(sharedPreference);
    } else {
      prevAppVer = version.prevAppVer ?? '';
      prevAppVerNum = version.prevAppVerNum ?? '';
    }
  }

  Future<void> save(SharedPreferences sharedPreference) async {
    await sharedPreference.setString('appVer', appVer);
    await sharedPreference.setString('appVerNum', appVerNum);
    await sharedPreference.setString('prevAppVer', prevAppVer);
    await sharedPreference.setString('prevAppVerNum', prevAppVerNum);
  }
}
