import 'package:rdc_flutter_sdk/src/model/rabbit_data_config.dart';
import 'package:rdc_flutter_sdk/src/model/rabbit_enum.dart';
import 'package:rdc_flutter_sdk/src/model/rabbit_request.dart';
import 'package:rxdart/subjects.dart';

import 'controllers/rabbit_config_controller.dart';
import 'controllers/user_info_controller.dart';

abstract class RabbitDataInstance {
  Future<RabbitDataInstance> initializeInstance(RabbitDataConfig config);

  late RabbitConfigController config;
  late UserInfoController userInfo;

  /*---------- override config ----------- */
  void setAPIKey(String key);
  void setEncryptionKey(String key);
  void setRotationTime(int min);
  void setDataCollectionType(DataCollectionType type);
  void setRetentionDays(int date);
  void setDeleteAfterSent(bool value);
  void setOfflineMode(bool value);
  void setRetryOnFailed(int time);
  void setTriggerCondition({int cpu = 0, int memory = 0, int batteryLevel = 0});
  void setSessionExpire(int min);
  void setSessionAutoExpire(int min);
  void setConsent(bool? value);
  void setPermissionMaid(bool value);
  void setStorageCondition({required int min, required int max});
  Future<void> setMemberId(String memberId);
  Future<void> setSsoId(String ssoId);
  /*---------- override config ----------- */

  /*---------- event ----------- */
  Future<void> addEvent(
      {required String eventName,
      required String eventValue,
      Map<String, String>? dataLayer});
  Future<List<RabbitRequest>> getEvents();
  Future<void> uploadEvent();
  Future<void> clearCache();
  Future<void> clearAll();
  Future<void> sessionStart();
  Future<void> sessionEnd();
  Future<void> setDebugMode(bool value);
  /*---------- event ----------- */

  /*---------- stream ----------- */
  late BehaviorSubject<Map<String, num>> condition;
  late BehaviorSubject<String> apiResult;
  late BehaviorSubject<String> changeDB;
  late BehaviorSubject<int> sizeDB;
  /*---------- stream ----------- */
}
